=================================
Welcome to cryptopher v 0.0.0
=================================

This is a trading analysis library.

Source code

  https://github.com/PesseCanoe/cryptopher
  
Features
--------

- Backtest analysis
- Implementation of basic strategy (eg. RSI)
- Strategy visualization
- Wrapper for getting data from several libraries


Quick Start
-----------

.. code:: bash

  pip install cryptopher 



